{% load date_extras %}

<div style="display: flex">
    <div style="width: 100%"></div>
    {% if meta and meta.created_at and meta.created_by %}
    <div class="metadata">Créé le {{meta.created_at|short_datetime}} par {{meta.created_by.username}}</div>
    {% endif %}
    {% if meta and meta.updated_at and meta.updated_by %}
    <div class="metadata">Modifié le {{meta.updated_at|short_datetime}} par {{meta.updated_by.username}}</div>
    {% endif %}
</div>

