<div class="col-md-4">
    <a onclick="send('{{report.name}}')" style="cursor:pointer; text-decoration: none">
    <i class="fa fa-file-pdf icon col" aria-hidden="true"></i>
    <h4 class="col" style="text-align: center;">{{report.label}}</h4>
    </a>
</div>
