<div class="form-group">
    <div class="col-sm-4">&nbsp;</div>
    <div class="col-sm-8">
        <div class="checkbox" style="margin: 2px;">
            <label>
                <input id="{{field.key}}"
                       name="{{field.key}}"
                       type="checkbox" {% if field.value %}checked{% endif %}/>
                {{field.label}}
            </label>
        </div>
    </div>
</div>